@@ -71,7 +71,9 @@ class Exceldefinition:
                     )
                 )
         except Exception:
-            raise ValueError("The JSON file structure is invalid.")
+            raise ValueError(
+                "The JSON file structure is invalid. Please check the documentation: https://github.com/SharryXu/jira-tool"
+            )
 
     def load_file(self, file: str):
         """
@@ -108,17 +110,22 @@ class Exceldefinition:
             column_raise_ranking,
         ) in self.get_columns():
             # Check Name cannot be empty
-            if column_name is None or len(column_name) == 0:
+            if type(column_name) is not str or len(column_name) == 0:
                 invalid_definitions.append(
                     f"Column name cannot be empty. Index: {column_index}"
                 )
                 continue
             # Check Missing/Duplicate Index
-            if column_index is None:
+            if type(column_index) is not int:
+                invalid_definitions.append(
+                    f"Column Index can only be number. Column: {column_name}"
+                )
+            elif column_index is None:
                 invalid_definitions.append(f"Missing Index. Column: {column_name}")
-            if column_index in exist_indexes:
+            elif column_index in exist_indexes:
                 invalid_definitions.append(f"Duplicate Index. Column: {column_name}")
-            exist_indexes.append(column_index)
+            else:
+                exist_indexes.append(column_index)
             # Check Property Type
             if column_type not in (
                 str,
@@ -128,40 +135,52 @@ class Exceldefinition:
                 Milestone,
                 float,
             ):
-                invalid_definitions.append(f"Invalid Type. Column: {column_name}")
+                invalid_definitions.append(
+                    f"Invalid Column Type. Column: {column_name}"
+                )
 
             # Check Sort
-            if column_require_sort is not bool:
+            if type(column_require_sort) is not bool:
                 invalid_definitions.append(
                     f"Require Sort can only be True/False. Column: {column_name}"
                 )
 
-            if column_sort_order is not bool:
+            if type(column_sort_order) is not bool:
                 invalid_definitions.append(
                     f"Sort Order can only be True(Descending)/False(Ascending). Column: {column_name}"
                 )
 
             # TODO: Currently only support different line weights.
-            if (
-                column_inline_weights > 0
-                and column_inline_weights in exist_inline_weights
-            ):
+            if type(column_inline_weights) is not int:
                 invalid_definitions.append(
-                    f"Duplicate Inline Weights. Column: {column_name}"
+                    f"Inline Weights can only be number. Column: {column_name}"
                 )
-            exist_inline_weights.append(column_inline_weights)
+            else:
+                if (
+                    column_inline_weights > 0
+                    and column_inline_weights in exist_inline_weights
+                ):
+                    invalid_definitions.append(
+                        f"Duplicate Inline Weights. Column: {column_name}"
+                    )
+                exist_inline_weights.append(column_inline_weights)
 
-            # Check Support RaiseRanking or not
-            if column_type not in (bool,) and column_raise_ranking > 0:
+            if type(column_raise_ranking) is not int:
                 invalid_definitions.append(
-                    f"Column do not support Raise Ranking feature. Column: {column_name}"
+                    f"Raise Ranking can only be number. Column: {column_name}"
                 )
+            else:
+                # Check Support RaiseRanking or not
+                if column_type not in (bool,) and column_raise_ranking > 0:
+                    invalid_definitions.append(
+                        f"Column do not support Raise Ranking feature. Column: {column_name}"
+                    )
 
         return invalid_definitions
 
     @staticmethod
     def convert_str_to_type(type_str: str) -> type:
-        if type_str is None:
+        if type_str is None or type(type_str) is not str:
             return None
         type_str = str(type_str).strip().lower()
         if type_str.lower() == "str":
