@@ -13,7 +13,7 @@ except ImportError:
 
 import openpyxl
 
-from .excel_defination import *
+from .excel_definition import *
 from .milestone import *
 from .priority import *
 from .sprint_schedule import *
@@ -32,7 +32,7 @@ warnings.simplefilter(action="ignore", category=UserWarning)
 
 def read_excel_file(
     file: str,
-    excel_defination: ExcelDefination,
+    excel_definition: Exceldefinition,
     sprint_schedule: SprintScheduleStore,
 ) -> tuple:
     """
@@ -41,8 +41,8 @@ def read_excel_file(
     :parm file:
         The excel file that you want to read
 
-    :parm excel_defination:
-        The excel column defination which is imported from the :py:class:`ExcelDefination`
+    :parm excel_definition:
+        The excel column definition which is imported from the :py:class:`Exceldefinition`
 
     :parm sprint_schedule:
         The priority mapping for the :py:class:`Milestone` object.
@@ -60,12 +60,12 @@ def read_excel_file(
     wb = openpyxl.load_workbook(file)
     sheet = wb.active
 
-    # The count of column is taking from the defination file to avoid too many columns inside the excel file.
+    # The count of column is taking from the definition file to avoid too many columns inside the excel file.
     # Also, need to avoid exceed the range of the actual count.
-    if excel_defination.column_count > sheet.max_column:
+    if excel_definition.column_count > sheet.max_column:
         column_count = sheet.max_column
     else:
-        column_count = excel_defination.column_count
+        column_count = excel_definition.column_count
 
     max_column_index = chr(65 + column_count - 1)
 
@@ -85,8 +85,8 @@ def read_excel_file(
 
     stories = []
 
-    excel_defination_columns = excel_defination.get_columns()
-    storyFactory = StoryFactory(excel_defination_columns)
+    excel_definition_columns = excel_definition.get_columns()
+    storyFactory = StoryFactory(excel_definition_columns)
 
     for row in rows:
         if _should_skip(row):
@@ -94,10 +94,10 @@ def read_excel_file(
 
         story: Story = storyFactory.create_story()
         for column_index in range(len(row)):
-            column = excel_defination_columns[column_index]
+            column = excel_definition_columns[column_index]
             story.set_value(column[2], column[1], row[column_index].value)
-            if column[2] is Milestone:
-                story[column[1]].calc_priority(sprint_schedule)
+
+        story.calc_sprint_schedule(sprint_schedule)
         stories.append(story)
 
     wb.close()
@@ -138,7 +138,7 @@ def output_to_csv_file(
 def output_to_excel_file(
     file: str,
     stories: "list[Story]",
-    excel_defination: ExcelDefination,
+    excel_definition: Exceldefinition,
     columns_in_excel: "list[str]" = None,
     over_write: bool = True,
 ):
@@ -151,11 +151,11 @@ def output_to_excel_file(
     :parm stories:
         A list of :py:class:`Story` which need to be wrote to the excel
 
-    :parm excel_defination:
-        The excel column defination which is imported from the :py:class:`ExcelDefination`
+    :parm excel_definition:
+        The excel column definition which is imported from the :py:class:`Exceldefinition`
 
     :parm columns_in_excel:
-        Using separate column names instead of importing from the :py:class:`ExcelDefination`. Usually, it comes from the input excel file.
+        Using separate column names instead of importing from the :py:class:`Exceldefinition`. Usually, it comes from the input excel file.
 
     :parm over_write:
         Whether or not the exist output file will be over-write.
@@ -172,13 +172,13 @@ def output_to_excel_file(
     wb = openpyxl.Workbook()
     sheet = wb.active
 
-    excel_defination_columns = excel_defination.get_columns()
+    excel_definition_columns = excel_definition.get_columns()
 
     # Use original excel column name first.
     columns = columns_in_excel
     if columns is None:
         columns = [
-            column_name for _, column_name, _, _, _, _, _ in excel_defination_columns
+            column_name for _, column_name, _, _, _, _, _ in excel_definition_columns
         ]
 
     for column_index in range(len(columns)):
@@ -187,7 +187,7 @@ def output_to_excel_file(
 
     if stories is not None:
         for row_index in range(len(stories)):
-            for column_index, column_name, _, _, _, _, _ in excel_defination_columns:
+            for column_index, column_name, _, _, _, _, _ in excel_definition_columns:
                 cell = sheet.cell(row=row_index + 2, column=column_index)
                 cell.value = stories[row_index].format_value(column_name)
 
@@ -198,7 +198,7 @@ def output_to_excel_file(
 def process_excel_file(
     input_file: str,
     output_file: str,
-    excel_defination_config: str = None,
+    excel_definition_config: str = None,
     sprint_schedule_config: str = None,
     over_write: bool = True,
 ):
@@ -214,7 +214,7 @@ def process_excel_file(
     :parm sprint_schedule_config:
         The JSON file which contains the priority list to calculate the :py:class:`Milestone`
 
-    :parm excel_defination_config:
+    :parm excel_definition_config:
         The JSON file which contains the input excel file's structure.
 
     :parm over_write:
@@ -230,42 +230,42 @@ def process_excel_file(
         sprint_schedule.load_file(sprint_schedule_config)
         print("Using custom sprint schedule...")
 
-    excel_defination = ExcelDefination()
-    if excel_defination_config is None:
-        excel_defination.load(
-            files("jira_tool.assets").joinpath("excel_defination.json").read_text()
+    excel_definition = Exceldefinition()
+    if excel_definition_config is None:
+        excel_definition.load(
+            files("jira_tool.assets").joinpath("excel_definition.json").read_text()
         )
-        print("Using default excel defination...")
+        print("Using default excel definition...")
     else:
-        excel_defination.load_file(excel_defination_config)
-        print("Using custom excel defination...")
+        excel_definition.load_file(excel_definition_config)
+        print("Using custom excel definition...")
 
-    validation_result = excel_defination.validate()
+    validation_result = excel_definition.validate()
     if len(validation_result) != 0:
         for item in validation_result:
             print(item)
         return
 
     excel_columns, stories = read_excel_file(
-        input_file, excel_defination, sprint_schedule
+        input_file, excel_definition, sprint_schedule
     )
 
     if stories is None:
         print("There are no stories inside the excel file.")
         return
 
-    sort_strategy_priorities = excel_defination.get_sort_strategy_priorities()
+    sort_strategy_priorities = excel_definition.get_sort_strategy_priorities()
 
     for sort_strategy in sort_strategy_priorities:
         if sort_strategy.lower() in "InlineWeights".lower():
             stories = sorted(stories, reverse=True)
         elif sort_strategy.lower() in "SortOrder".lower():
-            sort_stories_by_property_and_order(stories, excel_defination)
+            sort_stories_by_property_and_order(stories, excel_definition)
         elif sort_strategy.lower() in "RaiseRanking".lower():
-            stories = sort_stories_by_raise_ranking(stories, excel_defination)
+            stories = sort_stories_by_raise_ranking(stories, excel_definition)
 
     output_to_excel_file(
-        output_file, stories, excel_defination, excel_columns, over_write
+        output_file, stories, excel_definition, excel_columns, over_write
     )
 
     print("%s has been saved.", output_file)
