@@ -28,7 +28,10 @@ class Milestone(object):
             self.priority = sprint_schedule.get_priority(self.sprint)
 
     def __str__(self) -> str:
-        return self.raw
+        if self.raw is None:
+            return ""
+        else:
+            return self.raw
 
     def __lt__(self, __o: object) -> bool:
         if self.priority < __o.priority:
@@ -47,6 +50,3 @@ class Milestone(object):
             return True
         else:
             return False
-
-    def __str__(self):
-        return self.raw
